@@ -1,4 +1,4 @@
-test_that("rolling_time_varying_mvp returns a RollingWindow R6 object", {
+test_that("expanding_tvmvp returns a ExpandingWindow R6 object", {
   set.seed(123)
   T <- 100  # Number of time periods
   p <- 20   # Number of assets
@@ -7,7 +7,7 @@ test_that("rolling_time_varying_mvp returns a RollingWindow R6 object", {
   tmp <- TVMVP$new()
   tmp$set(data = returns)
 
-  mvp_result <- rolling_time_varying_mvp(
+  mvp_result <- expanding_tvmvp(
     tmp,
     initial_window = 60,
     rebal_period   = 5,
@@ -17,7 +17,7 @@ test_that("rolling_time_varying_mvp returns a RollingWindow R6 object", {
   )
 
   # Check that result is an R6 object of class RollingWindow
-  expect_true(inherits(mvp_result, "RollingWindow"))
+  expect_true(inherits(mvp_result, "ExpandingWindow"))
 
   # Optionally check something else
 })
